import sys
import typing
from . import helpers

GenericType = typing.TypeVar("GenericType")

def class_filter(cls_parent, kw): ...
def ui_draw_filter_register(
    ui_ignore_classes,
    ui_ignore_operator,
    ui_ignore_property,
    ui_ignore_menu,
    ui_ignore_label,
): ...
def ui_draw_filter_unregister(ui_ignore_store): ...
